# coding: utf-8

"""
    VeeRoute.UD

    VeeRoute.UD API  # noqa: E501

    The version of the OpenAPI document: 2.9.162365
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.orders_filter import OrdersFilter  # noqa: E501
from vrt_ud.rest import ApiException

class TestOrdersFilter(unittest.TestCase):
    """OrdersFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrdersFilter
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.orders_filter.OrdersFilter()  # noqa: E501
        if include_optional :
            return OrdersFilter(
                time_window = vrt_ud.models.time_window.TimeWindow(
                    from = '2020-10-21T09:30+03:00', 
                    to = '2020-10-21T19:45Z', ), 
                zone = 'spb', 
                keys = [
                    'order3991'
                    ], 
                business_keys = [
                    'order_bussiness_11'
                    ]
            )
        else :
            return OrdersFilter(
        )

    def testOrdersFilter(self):
        """Test OrdersFilter"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
